==> luna3-2.13.64-py3-none-any.whl: luna3/backport4/mixins/accounts.py <==
"""
Module realize accounts mixin
"""
from typing import Awaitable, Optional, Union

try:
    from typing import Literal
except ImportError:
    from typing_extensions import Literal

from luna3.common.luna_response import LunaResponse
from luna3.common.requests import RequestPayload
from luna3.lunavl.mixins import MixinStub


class AccountsMixin(MixinStub):
    """Accounts mixin for accounts requests"""

    def createAccount(
        self,
        login: str,
        password: str,
        accountType: Literal["advanced_user", "user"],
        description: Optional[str] = None,
        accountId: Optional[str] = None,
        **kwargs,
    ) -> Union[Awaitable[LunaResponse], LunaResponse]:
        """
        Create new account

        Args:
            login: account login
            password: account password
            accountType: account type
            description: account description
            accountId: account id

        Returns:
            class:`~.LunaResponse` or *asyncio coroutine* with *LunaResponse*.
            In body of :class: `~.LunaResponse` json with created account id will be returned.
        """
        data = dict(login=login, password=password, account_type=accountType)
        if description is not None:
            data["description"] = description
        payload = RequestPayload.buildJson(body=data)
        payload.applyAccountIdHeader(accountId)
        return self.makeRequest(f"{self.baseUri}/accounts", "POST", body=payload, **kwargs)

    def getAccount(
        self,
        **kwargs,
    ) -> Union[Awaitable[LunaResponse], LunaResponse]:
        """
        Get account.

        Returns:
            class:`~.LunaResponse` or *asyncio coroutine* with *LunaResponse*.
            In body of :class: `~.LunaResponse` json with account will be returned.
        """
        return self.makeRequest(f"{self.baseUri}/account", "GET", **kwargs)

    def patchAccount(
        self,
        login: Optional[str] = None,
        password: Optional[str] = None,
        accountType: Optional[Literal["advanced_user", "user"]] = None,
        description: Optional[str] = None,
        **kwargs,
    ) -> Union[Awaitable[LunaResponse], LunaResponse]:
        """
        Patch account.

        Args:
            login: account login
            password: account password
            accountType: account type
            description: account description

        Returns:
            class:`~.LunaResponse` or *asyncio coroutine* with *LunaResponse*.
            In body of :class: `~.LunaResponse` 204 status code will be returned.
        """
        data = {}
        if login is not None:
            data["login"] = login
        if password is not None:
            data["password"] = password
        if accountType is not None:
            data["account_type"] = accountType
        if description is not None:
            data["description"] = description
        payload = RequestPayload.buildJson(body=data)
        return self.makeRequest(f"{self.baseUri}/account", "PATCH", body=payload, **kwargs)

    def verifyAccount(
        self,
        accountId: Optional[str] = None,
        login: Optional[str] = None,
        password: Optional[str] = None,
        **kwargs,
    ) -> Union[Awaitable[LunaResponse], LunaResponse]:
        """
        Verify account data.

        Args:
            accountId: account id
            login: account login
            password: account password
        Returns:
            class:`~.LunaResponse` or *asyncio coroutine* with *LunaResponse*.
            In body of :class: `~.LunaResponse` 204 status code will be returned.
        """
        data = {}
        if login is not None:
            data["login"] = login
        if password is not None:
            data["password"] = password
        if accountId is not None:
            data["account_id"] = accountId
        payload = RequestPayload.buildJson(body=data)
        return self.makeRequest(f"{self.baseUri}/credentials_verifier", "POST", body=payload, **kwargs)

==> luna3-2.14.65-py3-none-any.whl: luna3/backport4/mixins/accounts.py <==
"""
Module realize accounts mixin
"""

from typing import Awaitable, Optional, Union

try:
    from typing import Literal
except ImportError:
    from typing_extensions import Literal

from luna3.common.luna_response import LunaResponse
from luna3.common.requests import RequestPayload
from luna3.lunavl.mixins import MixinStub


class AccountsMixin(MixinStub):
    """Accounts mixin for accounts requests"""

    def createAccount(
        self,
        login: str,
        password: str,
        accountType: Literal["advanced_user", "user"],
        description: Optional[str] = None,
        accountId: Optional[str] = None,
        **kwargs,
    ) -> Union[Awaitable[LunaResponse], LunaResponse]:
        """
        Create new account

        Args:
            login: account login
            password: account password
            accountType: account type
            description: account description
            accountId: account id

        Returns:
            class:`~.LunaResponse` or *asyncio coroutine* with *LunaResponse*.
            In body of :class: `~.LunaResponse` json with created account id will be returned.
        """
        data = {"login": login, "password": password, "account_type": accountType}
        if description is not None:
            data["description"] = description
        payload = RequestPayload.buildJson(body=data)
        payload.applyAccountIdHeader(accountId)
        return self.makeRequest(f"{self.baseUri}/accounts", "POST", body=payload, **kwargs)

    def getAccount(
        self,
        **kwargs,
    ) -> Union[Awaitable[LunaResponse], LunaResponse]:
        """
        Get account.

        Returns:
            class:`~.LunaResponse` or *asyncio coroutine* with *LunaResponse*.
            In body of :class: `~.LunaResponse` json with account will be returned.
        """
        return self.makeRequest(f"{self.baseUri}/account", "GET", **kwargs)

    def patchAccount(
        self,
        newLogin: Optional[str] = None,
        newPassword: Optional[str] = None,
        newAccountType: Optional[Literal["advanced_user", "user"]] = None,
        newDescription: Optional[str] = None,
        **kwargs,
    ) -> Union[Awaitable[LunaResponse], LunaResponse]:
        """
        Patch account.

        Args:
            newLogin: account login
            newPassword: account password
            newAccountType: account type
            newDescription: account description

        Returns:
            class:`~.LunaResponse` or *asyncio coroutine* with *LunaResponse*.
            In body of :class: `~.LunaResponse` 204 status code will be returned.
        """
        data = {}
        if newLogin is not None:
            data["login"] = newLogin
        if newPassword is not None:
            data["password"] = newPassword
        if newAccountType is not None:
            data["account_type"] = newAccountType
        if newDescription is not None:
            data["description"] = newDescription
        payload = RequestPayload.buildJson(body=data)
        return self.makeRequest(f"{self.baseUri}/account", "PATCH", body=payload, **kwargs)

    def verifyAccount(
        self,
        accountId: Optional[str] = None,
        login: Optional[str] = None,
        password: Optional[str] = None,
        **kwargs,
    ) -> Union[Awaitable[LunaResponse], LunaResponse]:
        """
        Verify account data.

        Args:
            accountId: account id
            login: account login
            password: account password
        Returns:
            class:`~.LunaResponse` or *asyncio coroutine* with *LunaResponse*.
            In body of :class: `~.LunaResponse` 204 status code will be returned.
        """
        data = {}
        if login is not None:
            data["login"] = login
        if password is not None:
            data["password"] = password
        if accountId is not None:
            data["account_id"] = accountId
        payload = RequestPayload.buildJson(body=data)
        return self.makeRequest(f"{self.baseUri}/credentials_verifier", "POST", body=payload, **kwargs)
